@@ -25,6 +25,8 @@ from .output_formatter import OutputFormatter
 from .utils import (URLHelper, RawHelper, extend_config,
                     get_available_language_codes, extract_meta_refresh)
 from scraper.video_extractor import VideoExtractor
+from scraper.urls import extract_domain
+
 
 __title__ = 'scraper'
 __author__ = 'Lucas Ou-Yang'
@@ -460,6 +462,7 @@ class Article(object):
                     # lots of cells span cols and rows so lets deal with that
                     cspan = int(cell.get('colspan', 1))
                     rspan = int(cell.get('rowspan', 1))
+                    # noinspection PyPep8
                     l = 0
                     for k in range(rspan):
                         # Shifts to the first empty cell of this row
@@ -604,6 +607,9 @@ class Article(object):
             raise Exception("authors input must be list!")
         if authors:
             self.authors = authors[:self.config.MAX_AUTHORS]
+        else:
+            # if unable to determine article's author, use toplevel domain from url for credits
+            self.authors.append(extract_domain(self.url))
 
     def set_summary(self, summary):
         """Summary here refers to a paragraph of text from the
