@@ -35,6 +35,6 @@ class Sources:
         # type: () -> list
         return self.source.category_urls()
 
-    def download(self):
+    def build(self):
         # type: () -> None
         self.article.build()
